@@ -29,6 +29,20 @@ pub struct ModuleOrConfig(Either<Module, Config>);
 #[derive(Debug, Clone, Span, Parse, Format)]
 pub struct Form(self::forms::Form);
 
+impl Form {
+    fn get(&self) -> &self::forms::Form {
+        &self.0
+    }
+
+    pub(crate) fn is_func_spec(&self) -> bool {
+        matches!(self.0, self::forms::Form::FunSpec(_))
+    }
+
+    pub(crate) fn is_func_decl(&self) -> bool {
+        matches!(self.0, self::forms::Form::FunDecl(_))
+    }
+}
+
 /// One of [types].
 #[derive(Debug, Clone, Span, Parse, Format)]
 pub struct Type(self::types::UnionType);
@@ -47,4 +61,8 @@ impl Expr {
     pub(crate) fn get(&self) -> &self::expressions::FullExpr {
         &self.0
     }
+
+    pub(crate) fn is_block(&self) -> bool {
+        self.0.is_block()
+    }
 }
