@@ -34,4 +34,16 @@ mod tests {
             crate::assert_format!(text, Expr);
         }
     }
+
+    #[test]
+    fn tagged_tuple_works() {
+        let texts = [indoc::indoc! {"
+            %---10---|%---20---|
+            {error, {Foo, Bar,
+                     Baz},
+                    qux}"}];
+        for text in texts {
+            crate::assert_format!(text, Expr);
+        }
+    }
 }
