@@ -1,21 +1,22 @@
 //! Erlang top-level components such as attributes, directives or declarations.
 use crate::format::{Format, Formatter, Indent, Newline};
 use crate::items::atoms::{
-    CallbackAtom, DefineAtom, IncludeAtom, IncludeLibAtom, OpaqueAtom, RecordAtom, SpecAtom,
-    TypeAtom,
+    CallbackAtom, DefineAtom, ExportAtom, ExportTypeAtom, IncludeAtom, IncludeLibAtom, OpaqueAtom,
+    RecordAtom, SpecAtom, TypeAtom,
 };
 use crate::items::components::{
-    Clauses, CommaDelimiter, Either, Element, Maybe, Never, NonEmptyItems, Null, Params,
-    Parenthesized, TupleLike, WithArrow, WithGuard,
+    Clauses, CommaDelimiter, Either, Element, Items, Maybe, Never, NonEmptyItems, Null, Params,
+    Parenthesized, WithArrow, WithGuard,
 };
 use crate::items::expressions::components::FunctionClause;
-use crate::items::keywords::IfKeyword;
+use crate::items::keywords::{ElseKeyword, IfKeyword};
 use crate::items::macros::{MacroName, MacroReplacement};
 use crate::items::symbols::{
-    CloseParenSymbol, ColonSymbol, CommaSymbol, DotSymbol, DoubleColonSymbol, HyphenSymbol,
-    MatchSymbol, OpenParenSymbol,
+    CloseBraceSymbol, CloseParenSymbol, CloseSquareSymbol, ColonSymbol, CommaSymbol, DotSymbol,
+    DoubleColonSymbol, HyphenSymbol, MatchSymbol, OpenBraceSymbol, OpenParenSymbol,
+    OpenSquareSymbol, SlashSymbol,
 };
-use crate::items::tokens::{AtomToken, LexicalToken, StringToken, VariableToken};
+use crate::items::tokens::{AtomToken, IntegerToken, LexicalToken, StringToken, VariableToken};
 use crate::items::Expr;
 use crate::items::Type;
 use crate::parse::Parse;
@@ -30,6 +31,7 @@ pub(super) enum Form {
     FunDecl(FunDecl),
     TypeDecl(TypeDecl),
     RecordDecl(RecordDecl),
+    Export(ExportAttr),
     Attr(Attr),
 }
 
@@ -44,7 +46,9 @@ pub struct RecordDecl(AttrLike<RecordAtom, RecordDeclValue>);
 struct RecordDeclValue {
     name: AtomToken,
     comma: CommaSymbol,
-    fields: TupleLike<RecordField>,
+    open: OpenBraceSymbol,
+    fields: Items<RecordField>,
+    close: CloseBraceSymbol,
 }
 
 impl Format for RecordDeclValue {
@@ -53,8 +57,18 @@ impl Format for RecordDeclValue {
             self.name.format(fmt);
             self.comma.format(fmt);
             fmt.add_space();
-            fmt.subregion(Indent::inherit(), Newline::IfTooLongOrMultiLine, |fmt| {
-                self.fields.format(fmt)
+            self.open.format(fmt);
+            fmt.subregion(Indent::Offset(2), Newline::Always, |fmt| {
+                self.fields.format(fmt);
+            });
+
+            let newline = if self.fields.items().is_empty() {
+                Newline::Never
+            } else {
+                Newline::Always
+            };
+            fmt.subregion(Indent::Offset(1), newline, |fmt| {
+                self.close.format(fmt);
             });
         });
     }
@@ -69,6 +83,7 @@ struct RecordField {
 
 impl Format for RecordField {
     fn format(&self, fmt: &mut Formatter) {
+        fmt.add_newline();
         self.name.format(fmt);
         if let Some((x, y)) = self.default.get() {
             fmt.add_space();
@@ -178,6 +193,61 @@ pub struct FunDecl {
     dot: DotSymbol,
 }
 
+/// `-` `export|export_type` `$EXPORTS`
+///
+/// - $EXPORTS: `(` (`$EXPORT`,`?)* `)`
+/// - $EXPORT: [AtomToken] `/` [IntegerToken]
+#[derive(Debug, Clone, Span, Parse, Format)]
+pub struct ExportAttr(AttrLike<Either<ExportAtom, ExportTypeAtom>, ExportItems>);
+
+#[derive(Debug, Clone, Span, Parse)]
+struct ExportItems {
+    open: OpenSquareSymbol,
+    items: Items<ExportItem, CommaDelimiter>,
+    close: CloseSquareSymbol,
+}
+
+impl Format for ExportItems {
+    fn format(&self, fmt: &mut Formatter) {
+        self.open.format(fmt);
+
+        let items = self.items.items();
+        let delimiters = self.items.delimiters();
+        if !items.is_empty() {
+            fmt.subregion(Indent::CurrentColumn, Newline::Never, |fmt| {
+                items.first().expect("unreachable").format(fmt);
+
+                for (prev_item, (item, delimiter)) in items
+                    .iter()
+                    .zip(items.iter().skip(1).zip(delimiters.iter()))
+                {
+                    delimiter.format(fmt);
+
+                    let is_same_group = prev_item.name.value() == item.name.value()
+                        && prev_item.start_position().line() + 1 >= item.end_position().line();
+                    if is_same_group {
+                        fmt.subregion(Indent::inherit(), Newline::IfTooLong, |fmt| {
+                            item.format(fmt)
+                        });
+                    } else {
+                        fmt.add_newline();
+                        item.format(fmt);
+                    }
+                }
+            });
+        }
+
+        self.close.format(fmt);
+    }
+}
+
+#[derive(Debug, Clone, Span, Parse, Format)]
+struct ExportItem {
+    name: AtomToken,
+    slash: SlashSymbol,
+    arity: IntegerToken,
+}
+
 /// `-` `$NAME` `$ARGS`? `.`
 ///
 /// - $NAME: [AtomToken] | `if`
@@ -186,7 +256,7 @@ pub struct FunDecl {
 #[derive(Debug, Clone, Span, Parse, Format)]
 pub struct Attr(AttrLike<AttrName, AttrValue, Null>);
 
-type AttrName = Either<AtomToken, IfKeyword>;
+type AttrName = Either<AtomToken, Either<IfKeyword, ElseKeyword>>;
 type AttrValue = NonEmptyItems<Expr>;
 
 #[derive(Debug, Clone, Span, Parse)]
@@ -239,10 +309,8 @@ impl DefineDirective {
     pub fn replacement(&self) -> &[LexicalToken] {
         self.replacement.tokens()
     }
-}
 
-impl Format for DefineDirective {
-    fn format(&self, fmt: &mut Formatter) {
+    pub fn format_with_indent(&self, fmt: &mut Formatter, replacement_indent: Option<usize>) {
         self.hyphen.format(fmt);
         self.define.format(fmt);
         self.open.format(fmt);
@@ -251,7 +319,11 @@ impl Format for DefineDirective {
             self.variables.format(fmt);
             self.comma.format(fmt);
             fmt.add_space();
-            fmt.subregion(Indent::inherit(), Newline::IfTooLongOrMultiLine, |fmt| {
+
+            let indent = replacement_indent
+                .map(Indent::Absolute)
+                .unwrap_or(Indent::inherit());
+            fmt.subregion(indent, Newline::IfTooLongOrMultiLine, |fmt| {
                 self.replacement.format(fmt)
             });
         });
@@ -260,6 +332,12 @@ impl Format for DefineDirective {
     }
 }
 
+impl Format for DefineDirective {
+    fn format(&self, fmt: &mut Formatter) {
+        self.format_with_indent(fmt, None);
+    }
+}
+
 /// `-` (`include` | `include_lib`) `(` `$PATH` `)` `.`
 ///
 /// - $PATH: [StringToken]
@@ -423,15 +501,21 @@ mod tests {
     fn record_decl_works() {
         let texts = [
             "-record(foo, {}).",
-            "-record(foo, {foo}).",
             indoc::indoc! {"
-            -record(foo,
-                    {foo, bar})."},
+            -record(foo, {
+                      foo
+                     })."},
             indoc::indoc! {"
-            -record(rec,
-                    {field1 = [] :: Type1,
-                     field2,
-                     field3 = 421})."},
+            -record(foo, {
+                      foo,
+                      bar
+                     })."},
+            indoc::indoc! {"
+            -record(rec, {
+                      field1 = [] :: Type1,
+                      field2,
+                      field3 = 421
+                     })."},
         ];
         for text in texts {
             crate::assert_format!(text, Form);
