@@ -270,11 +270,15 @@ mod tests {
         let texts = [
             indoc::indoc! {"
             -define(FOO, bar).
+
+
             baz() ->
                 ?FOO.
             "},
             indoc::indoc! {"
             -define(FOO, bar).
+
+
             baz() ->
                 ?FOO().
             "},
@@ -282,6 +286,8 @@ mod tests {
             -define(FOO, bar).
             -define(FOO(),
                     bar bar).
+
+
             baz() ->
                 ?FOO.
             "},
@@ -291,20 +297,26 @@ mod tests {
             "},
             indoc::indoc! {"
             -define(INC, 1 +).
+
+
             inc(A) ->
                 ?INC A.
             "},
             indoc::indoc! {"
             -define(FOO_OPEN,
                     foo().
+
             -define(FOO_CLOSE,
                     )).
+
+
             foo(A) ->
                 ?FOO_OPEN A?FOO_CLOSE.
             "},
             indoc::indoc! {"
             -define(EMPTY, ).
 
+
             ?EMPTY hello?EMPTY() ->
                 ?EMPTY?EMPTY world.
             ?EMPTY"},
@@ -320,6 +332,8 @@ mod tests {
             indoc::indoc! {"
             %---10---|%---20---|
             -define(FOO(), foo).
+
+
             foo() ->
                 ?FOO().
             "},
@@ -327,6 +341,8 @@ mod tests {
             %---10---|%---20---|
             -define(FOO(Bar),
                     {Bar, Baz}).
+
+
             qux() ->
                 ?FOO(quux).
             "},
@@ -335,6 +351,8 @@ mod tests {
             -define(FOO(Bar,
                         Baz),
                     {Bar, Baz}).
+
+
             qux() ->
                 ?FOO(begin
                          foo,
@@ -346,6 +364,7 @@ mod tests {
             indoc::indoc! {"
             -define(FOO(A), A).
 
+
             qux() ->
                 [?FOO(begin
                           foo,
@@ -360,12 +379,15 @@ mod tests {
             -define(bar(A), A).
             -define(baz(A), A).
 
+
             main() ->
                 ?baz(?bar(?foo)).
             "},
             indoc::indoc! {"
             -define(Foo(A),
                     ??A).
+
+
             bar() ->
                 ?Foo(10).
             "},
@@ -374,6 +396,8 @@ mod tests {
             -define(FOO(), foo).
             -define(FOO,
                     foo foo).
+
+
             foo() ->
                 ?FOO() + 10.
             "},
@@ -384,6 +408,8 @@ mod tests {
                         1,
                         2
                     end).
+
+
             foo() ->
                 ?FOO.
             "},
@@ -406,6 +432,7 @@ mod tests {
             -define(foo, [],[).
             -define(bar(A), A).
 
+
             main() ->
                 ?bar(?foo)
                 c].
@@ -414,6 +441,7 @@ mod tests {
             -define(foo, [],).
             -define(bar(A), A).
 
+
             main() ->
                 ?bar(?foo)
                 [c].
@@ -423,6 +451,7 @@ mod tests {
                     [1, 2, 3], [).
             -define(b(A), A).
 
+
             main() ->
                 ?b(?a a)
                 , c].
@@ -439,6 +468,8 @@ mod tests {
             indoc::indoc! {"
             %---10---|%---20---|
             -define(FOO(A), A).
+
+
             qux() ->
                 ?FOO(\"aaa\"
                      \"bbb\"  % comment
@@ -447,6 +478,8 @@ mod tests {
             indoc::indoc! {"
             %---10---|%---20---|
             -define(FOO, foo).
+
+
             qux(A) ->
                 case A of
                     a ->
@@ -457,6 +490,8 @@ mod tests {
             indoc::indoc! {"
             %---10---|%---20---|
             -define(a(X), X X).
+
+
             foo() ->
                 1 ?a(?a(+1)).
             "},
@@ -475,7 +510,10 @@ mod tests {
                     ?FOO
                         1
                     end).
+
             -define(FOO, begin).
+
+
             baz() ->
                 ?BAR.
             "},
@@ -483,8 +521,10 @@ mod tests {
             %---10---|%---20---|
             -define(FOO,
                     ?BAR(1)).
+
             -define(BAR(X), X).
 
+
             foo() ->
                 [?FOO].
             "},
@@ -501,6 +541,8 @@ mod tests {
             %---10---|%---20---|
             -define(a, ?b).
             -define(b, ?a).
+
+
             foo() ->
                 ?a == ?b.
             "},
@@ -517,4 +559,23 @@ mod tests {
             crate::assert_format!(text, Module);
         }
     }
+
+    #[test]
+    fn macro_and_binary_op() {
+        let texts = [indoc::indoc! {"
+            %---10---|%---20---|
+            -define(FOO,
+                    case bar of
+                        baz ->
+                            ok
+                    end).
+
+
+            foo() ->
+                ok = ?FOO.
+            "}];
+        for text in texts {
+            crate::assert_format!(text, Module);
+        }
+    }
 }
