@@ -1,4 +1,5 @@
 use crate::format::Format;
+use crate::items::components::Element;
 use crate::items::tokens::VariableToken;
 use crate::parse::{self, Parse, TokenStream};
 use crate::span::Span;
@@ -18,6 +19,6 @@ macro_rules! impl_parse {
     };
 }
 
-#[derive(Debug, Clone, Span, Format)]
+#[derive(Debug, Clone, Span, Format, Element)]
 pub struct UnderscoreVariable(VariableToken);
 impl_parse!(UnderscoreVariable, "_");
