@@ -1,9 +1,8 @@
 % From: http://www1.erlang.org/examples/examples-2.0.html
 connect(Host, User, Password) ->
-    {ftp_server, Host} ! {connect,
-                          self(),
-                          User,
-                          Password},
+    {ftp_server, Host} ! {connect, self(),
+                                   User,
+                                   Password},
     receive
         {ftp_server, Reply} ->
             Reply;
@@ -14,17 +13,27 @@ connect(Host, User, Password) ->
             timeout
     end.
 
+
 pwd(Handle) ->
     remote(Handle, pwd).
+
+
 cd(Handle, Dir) ->
     remote(Handle, {cd, Dir}).
+
+
 ls(Handle) ->
     remote(Handle, ls).
+
+
 get(Handle, File) ->
     remote(Handle, {get, File}).
+
+
 quit(Handle) ->
     remote(Handle, quit).
 
+
 remote(Handle, Op) ->
     Handle ! {self(), Op},
     receive
@@ -35,14 +44,20 @@ remote(Handle, Op) ->
             timeout
     end.
 
+
 lcd(Dir) ->
     file:set_cwd(Dir),
     lpwd().
+
+
 lpwd() ->
     cwd().
+
+
 lls() ->
     element(2, file:list_dir(cwd())).
 
+
 put(Handle, File) ->
     case file:read_file(File) of
         {ok, Contents} ->
