@@ -7,21 +7,37 @@
          ddd/0,
          eee/0,
          fff/0]).
--export([ggg/0, hhh/0]).
+-export([ggg/0,
+         hhh/0]).
+
 
 aaa() ->
     ok.
+
+
 bbb() ->
     ok.
+
+
 ccc() ->
     ok.
+
+
 ddd() ->
     ok.
+
+
 eee() ->
     ok.
+
+
 fff() ->
     ok.
+
+
 ggg() ->
     ok.
+
+
 hhh() ->
     ok.
